translate.misc.typecheck._TC_MissingAttrError

Package translate :: Package misc :: Package typecheck :: Class _TC_MissingAttrError |
[hide private]
[frames] | no frames]

# Class _TC_MissingAttrError

source code

Instance Methods | [hide private]
error_message(self) | source code
Inherited from `_TC_AttrException`: `__init__` Inherited from `_TC_Exception`: `format_bad_object` Inherited from `exceptions.Exception`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__str__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`

Method Details | [hide private]

### error_message(self) | source code
Overrides: _TC_Exception.error_message